#include <osgProducer/Version>

const char* osgProducerGetVersion()
{
    return "1.1";
}


const char* osgProducerGetLibraryName()
{
    return "OpenSceneGraph Producer Library";
}
